//
//  EditImageViewController.swift
//  IFS
//
//  Created by 曹云霄 on 2018/2/1.
//  Copyright © 2018年 上海勾芒信息科技有限公司. All rights reserved.
//

import UIKit

public typealias SaveImageBlock = (String) ->Void

class EditImageViewController: BaseViewController {

    var type: LOCATION_IMAGE_TYPE!
    
    /// 图片路径,查看时为本地路径，编辑时为网络路径
    var imageString :String!
    
    var attachmentImg: BaseEditImageView!
    
    /// 回调
    var saveImageBlock: SaveImageBlock?
    
    override func viewDidLoad() {
        super.viewDidLoad()

        uiConfigAction()
    }
    
    // MARK: - UI
    fileprivate func uiConfigAction() {
        self.fd_interactivePopDisabled = true;
        view.backgroundColor = kGaryColor
        attachmentImg = BaseEditImageView(frame: view.bounds)
        view.addSubview(attachmentImg)
        view.clipsToBounds = true
        if type == .EDIT {
            title = "编辑位置图"
            navigationItem.rightBarButtonItem = createButtonItem("保存", nil, self, #selector(EditImageViewController.saveButtonClickAction))
            let locationImg = BaseEditImageView(frame: CGRect(x: 0, y: 0, width: 40, height: 40))
            locationImg.image = UIImage(named: "location_red")
            locationImg.center = attachmentImg.center
            attachmentImg.addSubview(locationImg)
            attachmentImg.kf.setImage(with: URL(string: imageString), placeholder: loadingImage)
        }else {
            title = "查看位置图"
            attachmentImg.image = UIImage(contentsOfFile: imageString)
        }
    }
    
    // MARK: - 保存
    @objc func saveButtonClickAction() {
        guard saveImageBlock != nil else {
            ShowMessage("请先实现回调方法")
            return
        }
        popVC()
        let string = saveImage(currentImage: capture(attachmentImg), persent: 1, imageName: "editAttachmentImage")
        saveImageBlock!(string)
    }
    
    // MARK: - 保存图片附件至沙盒
    open func saveImage(currentImage: UIImage, persent: CGFloat, imageName: String) ->String {
        if let imageData = UIImageJPEGRepresentation(currentImage, persent) as NSData? {
            let fullPath = NSHomeDirectory().appending("/Documents/Files").appending(imageName)
            imageData.write(toFile: fullPath, atomically: true)
            return fullPath
        }
        return ""
    }
    
    // MARK: - 保存图片后回调
    func setSaveImageBlock(_ block: @escaping SaveImageBlock) {
        self.saveImageBlock = block
    }
    
    // MARK: - 截图
    func capture(_ view: UIImageView) ->UIImage {
        UIGraphicsBeginImageContextWithOptions(view.bounds.size, view.isOpaque, 0.0)
        view.layer.render(in: UIGraphicsGetCurrentContext()!)
        let image = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        return image!
    }
}
